@@ -1,13 +1,25 @@
 import os
 
 import yaml
+
+from gcasc.utils import os as uos
 from gcasc.utils.yaml_include import YamlIncluderConstructor
 from gcasc.utils.yaml_env import YamlEnvConstructor
 
+# includer relative to current path from which script is executed
 YamlIncluderConstructor.add_to_loader_class(
     loader_class=yaml.FullLoader, base_dir=os.path.dirname(os.path.realpath(__file__))
 )
 
+# includer relative to GitLab configuration file path
+config_path = uos.get_env_or_else(
+    ["GITLAB_CONFIG_FILE", "GITLAB_CONFIG_PATH"], "{0}/x".format(os.getcwd())
+).split("/")
+del config_path[-1]
+YamlIncluderConstructor.add_to_loader_class(
+    loader_class=yaml.FullLoader, base_dir="/".join(config_path)
+)
+
 YamlEnvConstructor.add_to_loader_class(loader_class=yaml.FullLoader)
 
 
@@ -22,24 +34,9 @@ class GitlabConfiguration(object):
 
         self.config = config
 
-    def __get(self, configuration):
+    def get(self, configuration):
         return self.config.get(configuration)
 
-    @property
-    def settings(self):
-        # type: ()->dict
-        return self.__get("settings")
-
-    @property
-    def license(self):
-        # type: ()->dict
-        return self.__get("license")
-
-    @property
-    def appearance(self):
-        # type: ()->dict
-        return self.__get("appearance")
-
     @staticmethod
     def from_file(path):
         # type: (str)->GitlabConfiguration
